@@ -33,8 +33,8 @@ TOPICWORDS = [{"token": "no", "tokenType": "negation"},{"token": "negative", "to
 {"token": "won(\'?)t", "tokenType": "negation"},{"token": "don(\'?)t", "tokenType": "negation"},
 {"token": "wouldn(\'?)t", "tokenType": "negation"},{"token": "denies", "tokenType": "negation"},
 {"token": "denied", "tokenType": "negation"},{"token": "\d+\.\d+", "tokenType": "numeric"},
-{"token": "\d+", "tokenType": "numeric"},{"token": "\d+\.\d+", "tokenType": "numeric", "suffix": "[^\s\d]*"},
-{"token": "\d+", "tokenType": "numeric","suffix": "[^\s\d]*"},{"token": "one", "tokenType": "numeric"},
+{"token": "\d+", "tokenType": "numeric"},{"token": "\d+\.\d+", "tokenType": "numeric", "suffix": "[^\s\d-]+"},
+{"token": "\d+", "tokenType": "numeric","suffix": "[^\s\d-]+"},{"token": "one", "tokenType": "numeric"},
 {"token": "two", "tokenType": "numeric"},{"token": "three", "tokenType": "numeric"},
 {"token": "four", "tokenType": "numeric"},{"token": "will", "tokenType": "future"},
 "reveal", "revealed","(\w("+punc+")?){1,2}\w"]
@@ -105,7 +105,7 @@ def pullOutTopics(topics, text, leftovers, noise):
                 suffix = topic["suffix"]
 
         ## find all relevant matches
-        for match in re.finditer("(\s|^)"+token+suffix+"(\s|"+"|\\".join(punc)+"\s|$)", text.lower(),overlapped=True):
+        for match in re.finditer("(\s|"+"|\\".join(punc)+"|^)"+token+suffix+"(\s|"+"|\\".join(punc)+"\s|$)", text.lower(),overlapped=True):
             topicmatches = re.finditer(token, text[match.start():match.end()].lower())
             allindexes = allindexes.union(range(match.start(), match.end()))
             for top in topicmatches:
